searchData={"items":[{"type":"module","title":"ExKits.Cache","doc":"This module provides a simple cache framework for storing and retrieving key-value pairs.","ref":"ExKits.Cache.html"},{"type":"module","title":"Examples - ExKits.Cache","doc":"Retrieve a value from the cache:\n\n    ```Elixir\n    storage = SomeImplement.new()\n    ExKits.Cache.fetch(storage, :key, [{:ttl, 3000}], fn _key ->\n      {:commit, \"value\"}\n    end)\n    |> IO.puts()\n    ```\n\nEvict a value from the cache:\n\n    ```Elixir\n    storage = SomeImplement.new()\n    ExKits.Cache.evict(storage, :key)\n    ```","ref":"ExKits.Cache.html#module-examples"},{"type":"module","title":"Security Warning - ExKits.Cache","doc":"This module provides a basic implementation of a cache framework\nand should not be used in production environments without proper security review and testing.","ref":"ExKits.Cache.html#module-security-warning"},{"type":"function","title":"ExKits.Cache.evict/2","doc":"This function removes the cached value with the given key from the cache storage.\n\nThe storage argument is a cache storage, which is an opaque data structure that holds the cached key-value pairs.\nThe key argument is the key of the value to remove from the cache.","ref":"ExKits.Cache.html#evict/2"},{"type":"function","title":"Examples - ExKits.Cache.evict/2","doc":"```Elixir\n    storage = SomeImplement.new()\n    ExKits.Cache.fetch(storage, :key, [], fn _key ->\n    {:commit, \"value\"}\n    end)\n    |> IO.puts()\n\n    ExKits.Cache.evict(storage, :key)\n    ```","ref":"ExKits.Cache.html#evict/2-examples"},{"type":"function","title":"ExKits.Cache.fetch/4","doc":"This function retrieves a value from the cache storage with the given key.\nIf the value is not found, the fallback function is called to generate a new value,\nwhich is then stored in the cache storage and returned. If the value is found, it is returned directly.\n\nThe storage argument is a cache storage, which is an opaque data structure that holds the cached key-value pairs.\nThe key argument is the key of the value to retrieve.\n\nThe opts argument is a list of put options, which can be used to set a time-to-live (TTL) for the cached value.\n\nThe fallback argument is a function that takes the cache key as an argument\nand returns either a {:commit, value} tuple to indicate that the value should be stored in the cache,\nor a {:ignore, value} tuple to indicate that the value should not be stored in the cache.\n\nThe function returns the cached value, or nil if the value is not found\nand the fallback function returns a {:ignore, value} tuple.\nIf the fallback function returns a {:commit, value} tuple, the value is stored in the cache storage and returned.","ref":"ExKits.Cache.html#fetch/4"},{"type":"function","title":"Examples - ExKits.Cache.fetch/4","doc":"iex> storage = SomeImplement.new()\n    iex> ExKits.Cache.fetch(storage, :key, [{:ttl, 3000}], fn _key ->\n      {:commit, \"value\"}\n    end)\n    |> IO.puts()","ref":"ExKits.Cache.html#fetch/4-examples"},{"type":"type","title":"ExKits.Cache.fallback/0","doc":"","ref":"ExKits.Cache.html#t:fallback/0"},{"type":"type","title":"ExKits.Cache.k/0","doc":"","ref":"ExKits.Cache.html#t:k/0"},{"type":"type","title":"ExKits.Cache.put_opts/0","doc":"","ref":"ExKits.Cache.html#t:put_opts/0"},{"type":"type","title":"ExKits.Cache.storage/0","doc":"","ref":"ExKits.Cache.html#t:storage/0"},{"type":"type","title":"ExKits.Cache.v/0","doc":"","ref":"ExKits.Cache.html#t:v/0"},{"type":"module","title":"ExKits.Cache.LRU","doc":"This modules implements a simple LRU cache, using 2 ets tables for it.\n\nFor using it, you need to start it:\n\n    iex> LRU.start_link(:my_cache, 1000)\n\nOr add it to your supervisor tree, like: `worker(LRU, [:my_cache, 1000])`","ref":"ExKits.Cache.LRU.html"},{"type":"module","title":"Using - ExKits.Cache.LRU","doc":"iex> LRU.start_link(:my_cache, 1000)\n    {:ok, #PID<0.60.0>}\n\n    iex> LRU.put(:my_cache, \"id\", \"value\")\n    :ok\n\n    iex> LRU.get(:my_cache, \"id\", touch = false)\n    \"value\"\n\nTo take some action when old keys are evicted from the cache when it is full,\nyou can pass an `:evict_fn` option to `LRU.start_link/3`. This is\nhelpful for cleaning up processes that depend on values in the cache, or\nlogging, or instrumentation of cache evictions etc.\n\n    iex> evict = fn(key,value) -> IO.inspect(\"#{key}=#{value} evicted\") end\n    iex> LRU.start_link(:my_cache, 10, evict_fn: evict)\n    {:ok, #PID<0.60.0>}","ref":"ExKits.Cache.LRU.html#module-using"},{"type":"module","title":"Design - ExKits.Cache.LRU","doc":"First ets table save the key values pairs, the second save order of inserted elements.","ref":"ExKits.Cache.LRU.html#module-design"},{"type":"function","title":"ExKits.Cache.LRU.delete/3","doc":"Removes the entry stored under the given `key` from cache.","ref":"ExKits.Cache.LRU.html#delete/3"},{"type":"function","title":"ExKits.Cache.LRU.get/4","doc":"Returns the `value` associated with `key` in `cache`. If `cache` does not contain `key`,\nreturns nil. `touch` defines, if the order in LRU should be actualized.","ref":"ExKits.Cache.LRU.html#get/4"},{"type":"function","title":"ExKits.Cache.LRU.put/4","doc":"Stores the given `value` under `key` in `cache`. If `cache` already has `key`, the stored\n`value` is replaced by the new one. This updates the order of LRU cache.","ref":"ExKits.Cache.LRU.html#put/4"},{"type":"function","title":"ExKits.Cache.LRU.select/3","doc":"Selects and returns the first value in the cache that matches the given condition.","ref":"ExKits.Cache.LRU.html#select/3"},{"type":"function","title":"Examples - ExKits.Cache.LRU.select/3","doc":"iex> LRU.select(:my_cache, fn value -> value > 10 end)\n    15\n\n#","ref":"ExKits.Cache.LRU.html#select/3-examples"},{"type":"function","title":"Parameters - ExKits.Cache.LRU.select/3","doc":"- `name` - The name of the cache.\n- `match_fun` - A function that takes a value and returns a boolean indicating whether it matches the condition.\n- `timeout` (optional) - The timeout value in milliseconds for the operation. Defaults to 5000.\n\n#","ref":"ExKits.Cache.LRU.html#select/3-parameters"},{"type":"function","title":"Returns - ExKits.Cache.LRU.select/3","doc":"The first value in the cache that matches the given condition, or `nil` if no match is found.","ref":"ExKits.Cache.LRU.html#select/3-returns"},{"type":"function","title":"ExKits.Cache.LRU.start_link/3","doc":"Creates an LRU of the given size as part of a supervision tree with a registered name","ref":"ExKits.Cache.LRU.html#start_link/3"},{"type":"function","title":"Options - ExKits.Cache.LRU.start_link/3","doc":"* `:evict_fn` - function that accepts (key, value) and takes some action when keys are\n    evicted when the cache is full.","ref":"ExKits.Cache.LRU.html#start_link/3-options"},{"type":"function","title":"ExKits.Cache.LRU.update/5","doc":"Updates a `value` in `cache`. If `key` is not present in `cache` then nothing is done.\n`touch` defines, if the order in LRU should be actualized. The function assumes, that\nthe element exists in a cache.","ref":"ExKits.Cache.LRU.html#update/5"},{"type":"type","title":"ExKits.Cache.LRU.t/0","doc":"","ref":"ExKits.Cache.LRU.html#t:t/0"},{"type":"behaviour","title":"ExKits.Cache.Storage","doc":"A cache storage module that provides a simple interface for storing and retrieving key-value pairs.","ref":"ExKits.Cache.Storage.html"},{"type":"behaviour","title":"Examples - ExKits.Cache.Storage","doc":"iex> storage = ExKits.Cache.Storage.new([])\n    iex> ExKits.Cache.Storage.put(storage, :key, \"value\", [])\n    :ok\n    iex> ExKits.Cache.Storage.get(storage, :key)\n    \"value\"","ref":"ExKits.Cache.Storage.html#module-examples"},{"type":"function","title":"ExKits.Cache.Storage.del/2","doc":"delete a key-value pair from the cache storage","ref":"ExKits.Cache.Storage.html#del/2"},{"type":"function","title":"Examples - ExKits.Cache.Storage.del/2","doc":"iex> storage = ExKits.Storage.ETS.new([])\n    iex> ExKits.Cache.Storage.del(storage, :key)\n    :ok","ref":"ExKits.Cache.Storage.html#del/2-examples"},{"type":"callback","title":"ExKits.Cache.Storage.del/2","doc":"","ref":"ExKits.Cache.Storage.html#c:del/2"},{"type":"function","title":"ExKits.Cache.Storage.get/2","doc":"get the value of a key from the cache storage","ref":"ExKits.Cache.Storage.html#get/2"},{"type":"function","title":"Examples - ExKits.Cache.Storage.get/2","doc":"iex> storage = ExKits.Storage.ETS.new([])\n    iex> ExKits.Cache.Storage.get(storage, :key)\n    nil","ref":"ExKits.Cache.Storage.html#get/2-examples"},{"type":"callback","title":"ExKits.Cache.Storage.get/2","doc":"","ref":"ExKits.Cache.Storage.html#c:get/2"},{"type":"callback","title":"ExKits.Cache.Storage.new/1","doc":"","ref":"ExKits.Cache.Storage.html#c:new/1"},{"type":"function","title":"ExKits.Cache.Storage.put/4","doc":"put a key-value pair into the cache storage","ref":"ExKits.Cache.Storage.html#put/4"},{"type":"function","title":"Examples - ExKits.Cache.Storage.put/4","doc":"iex> storage = ExKits.Storage.ETS.new([])\n    iex> ExKits.Cache.Storage.put(storage, :key, \"value\", [])\n    :ok","ref":"ExKits.Cache.Storage.html#put/4-examples"},{"type":"callback","title":"ExKits.Cache.Storage.put/4","doc":"","ref":"ExKits.Cache.Storage.html#c:put/4"},{"type":"type","title":"ExKits.Cache.Storage.k/0","doc":"","ref":"ExKits.Cache.Storage.html#t:k/0"},{"type":"type","title":"ExKits.Cache.Storage.opts/0","doc":"","ref":"ExKits.Cache.Storage.html#t:opts/0"},{"type":"type","title":"ExKits.Cache.Storage.put_opts/0","doc":"","ref":"ExKits.Cache.Storage.html#t:put_opts/0"},{"type":"type","title":"ExKits.Cache.Storage.t/0","doc":"","ref":"ExKits.Cache.Storage.html#t:t/0"},{"type":"type","title":"ExKits.Cache.Storage.v/0","doc":"","ref":"ExKits.Cache.Storage.html#t:v/0"},{"type":"module","title":"ExKits.Crypto.AES128CBC","doc":"This module provides functions for encrypting and decrypting data using the AES-128-CBC algorithm.","ref":"ExKits.Crypto.AES128CBC.html"},{"type":"module","title":"Examples - ExKits.Crypto.AES128CBC","doc":"secret_key = <<1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16>>\n    iv = <<17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32>>\n\n    plaintext = \"hello world\"\n    ciphertext = ExKits.Crypto.AES128CBC.encrypt(plaintext, secret_key, iv)\n    decrypted_text = ExKits.Crypto.AES128CBC.decrypt(ciphertext, secret_key, iv)\n\n    assert decrypted_text == plaintext","ref":"ExKits.Crypto.AES128CBC.html#module-examples"},{"type":"module","title":"Security Warning - ExKits.Crypto.AES128CBC","doc":"This module provides a basic implementation of the AES-128-CBC algorithm\nand should not be used in production environments without proper security review and testing.","ref":"ExKits.Crypto.AES128CBC.html#module-security-warning"},{"type":"function","title":"ExKits.Crypto.AES128CBC.decrypt/3","doc":"","ref":"ExKits.Crypto.AES128CBC.html#decrypt/3"},{"type":"function","title":"ExKits.Crypto.AES128CBC.encrypt/3","doc":"","ref":"ExKits.Crypto.AES128CBC.html#encrypt/3"},{"type":"type","title":"ExKits.Crypto.AES128CBC.iv/0","doc":"","ref":"ExKits.Crypto.AES128CBC.html#t:iv/0"},{"type":"type","title":"ExKits.Crypto.AES128CBC.key/0","doc":"","ref":"ExKits.Crypto.AES128CBC.html#t:key/0"},{"type":"module","title":"ExKits.Crypto.Fnv1a","doc":"Hashes terms using the FNV-1a 32-bit algorithm.","ref":"ExKits.Crypto.Fnv1a.html"},{"type":"module","title":"Examples - ExKits.Crypto.Fnv1a","doc":"iex> ExKits.Crypto.Fnv1a.hash({1, 2})\n    2761922969\n    iex> ExKits.Crypto.Fnv1a.hash(\"this thing\")\n    891900385","ref":"ExKits.Crypto.Fnv1a.html#module-examples"},{"type":"function","title":"ExKits.Crypto.Fnv1a.hash/1","doc":"","ref":"ExKits.Crypto.Fnv1a.html#hash/1"},{"type":"module","title":"ExKits.Crypto.SSL","doc":"This module provides functions for loading SSL certificates and keys from PEM-encoded data.","ref":"ExKits.Crypto.SSL.html"},{"type":"function","title":"ExKits.Crypto.SSL.load_pem/1","doc":"decode a PEM-encoded certificate or key","ref":"ExKits.Crypto.SSL.html#load_pem/1"},{"type":"function","title":"Examples - ExKits.Crypto.SSL.load_pem/1","doc":"iex> pem = File.read!(\"test/cert.pem\")\n    iex> ExKits.Crypto.SSL.load_pem(pem)\n    {:Certificate,\n      {:TBSCertificate, 0, 185741190458257600844327592762093690784461317564,\n      {:AlgorithmIdentifier, {1, 2, 840, 113549, 1, 1, 11}, <<5, 0>>},\n      {:rdnSequence,\n       [\n         [{:AttributeTypeAndValue, {2, 5, 4, 6}, <<19, 2, 65, 85>>}],\n         [{:AttributeTypeAndValue, {2, 5, 4, 8}, \"\f\nSome-State\"}],\n         [\n           {:AttributeTypeAndValue, {2, 5, 4, 10},\n            <<12, 24, 73, 110, 116, 101, 114, 110, 101, 116, 32, 87, 105, 100, 103,\n              105, 116, 115, 32, 80, 116, 121, 32, 76, 116, 100>>}\n         ]\n       ]},\n      {:Validity, {:utcTime, ~c\"231031062646Z\"}, {:utcTime, ~c\"241030062646Z\"}},\n      {:rdnSequence,\n       [\n         [{:AttributeTypeAndValue, {2, 5, 4, 6}, <<19, 2, 65, 85>>}],\n         [{:AttributeTypeAndValue, {2, 5, 4, 8}, \"\f\nSome-State\"}],\n         [\n           {:AttributeTypeAndValue, {2, 5, 4, 10},\n            <<12, 24, 73, 110, 116, 101, 114, 110, 101, 116, 32, 87, 105, 100, 103,\n              105, 116, 115, 32, 80, 116, 121, 32, 76, 116, 100>>}\n         ]\n       ]},\n      {:SubjectPublicKeyInfo,\n       {:AlgorithmIdentifier, {1, 2, 840, 113549, 1, 1, 1}, <<5, 0>>},\n       <<48, 130, 1, 10, 2, 130, 1, 1, 0, 216, 146, 215, 34, 63, 210, 99, 245, 173,\n         234, 130, 112, 247, 173, 214, 77, 124, 1, 187, 71, 140, 68, 143, 95, 147,\n         53, 124, 153, ...>>}, :asn1_NOVALUE, :asn1_NOVALUE, :asn1_NOVALUE},\n      {:AlgorithmIdentifier, {1, 2, 840, 113549, 1, 1, 11}, <<5, 0>>},\n      <<105, 241, 117, 217, 15, 215, 93, 45, 194, 176, 225, 141, 85, 200, 101, 214,\n       62, 69, 170, 91, 142, 107, 155, 200, 162, 31, 165, 214, 102, 37, 16, 39, 146,\n       177, 255, 255, 150, 38, 96, 58, 8, 60, 226, 31, 22, 29, ...>>}\n    }","ref":"ExKits.Crypto.SSL.html#load_pem/1-examples"},{"type":"function","title":"ExKits.Crypto.SSL.load_ssl/1","doc":"","ref":"ExKits.Crypto.SSL.html#load_ssl/1"},{"type":"module","title":"ExKits.Macros.Assertion","doc":"This module provides macros for performing assertions in Elixir code.","ref":"ExKits.Macros.Assertion.html"},{"type":"module","title":"Examples - ExKits.Macros.Assertion","doc":"```Elixir\nimport ExKits.Macros.Assertion\n\n# Perform a boolean assertion:\ndo_assert(fn -> 1 + 1 == 2 end, \"1 + 1 should equal 2\")\n\n# Perform an assertion that checks if an object exists:\nassert_exists(obj, \"Object should exist\")\n\n# Perform an assertion that checks if an object does not exist:\nassert_non_exists(obj, \"Object should not exist\")\n```","ref":"ExKits.Macros.Assertion.html#module-examples"},{"type":"macro","title":"ExKits.Macros.Assertion.assert_exists/2","doc":"","ref":"ExKits.Macros.Assertion.html#assert_exists/2"},{"type":"macro","title":"ExKits.Macros.Assertion.assert_non_exists/2","doc":"","ref":"ExKits.Macros.Assertion.html#assert_non_exists/2"},{"type":"macro","title":"ExKits.Macros.Assertion.do_assert/2","doc":"","ref":"ExKits.Macros.Assertion.html#do_assert/2"},{"type":"module","title":"ExKits.Macros.Constants","doc":"This module provides a macro for defining compile-time constants in Elixir code.","ref":"ExKits.Macros.Constants.html"},{"type":"module","title":"Examples - ExKits.Macros.Constants","doc":"```Elixir\n\n# Define a constant:\ndefmodule MyConst do\n  import ExKits.Macros.Constants\n\n  const :pi, 3.14159\nend\n\n# Use a constant:\n\nrequire MyConst\n@pi MyConst.pi()\n\nIO.puts(@pi)\n```","ref":"ExKits.Macros.Constants.html#module-examples"},{"type":"macro","title":"ExKits.Macros.Constants.const/2","doc":"","ref":"ExKits.Macros.Constants.html#const/2"},{"type":"module","title":"ExKits.Macros.FunctionGenerator","doc":"This module provides a macro for generating functions in Elixir code.\n```elixir\nrequire FunctionGenerator\n\nFunctionGenerator.generate_function :add, [a, b], do: a + b\n```","ref":"ExKits.Macros.FunctionGenerator.html"},{"type":"macro","title":"ExKits.Macros.FunctionGenerator.generate_function/3","doc":"","ref":"ExKits.Macros.FunctionGenerator.html#generate_function/3"},{"type":"module","title":"ExKits.Macros.Go","doc":"This module provides a macro for starting a new task under a given supervisor.","ref":"ExKits.Macros.Go.html"},{"type":"module","title":"Examples - ExKits.Macros.Go","doc":"Start a new task under a supervisor:\n\n    ExKits.Macros.go(MySupervisor, IO.puts(\"Hello, world!\"))","ref":"ExKits.Macros.Go.html#module-examples"},{"type":"macro","title":"ExKits.Macros.Go.go/2","doc":"","ref":"ExKits.Macros.Go.html#go/2"},{"type":"module","title":"ExKits.Storage.ETS","doc":"ExKits.Cache.Storage implementation by ETS","ref":"ExKits.Storage.ETS.html"},{"type":"function","title":"ExKits.Storage.ETS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExKits.Storage.ETS.html#child_spec/1"},{"type":"function","title":"ExKits.Storage.ETS.new/1","doc":"create a new ets based storage.\n2 options are supported:\n- name: ets name, default to :ets_cache\n- interval: interval to clean expired keys, default to 60_000 (1 minute)","ref":"ExKits.Storage.ETS.html#new/1"},{"type":"function","title":"ExKits.Storage.ETS.start_link/1","doc":"","ref":"ExKits.Storage.ETS.html#start_link/1"},{"type":"type","title":"ExKits.Storage.ETS.t/0","doc":"","ref":"ExKits.Storage.ETS.html#t:t/0"},{"type":"module","title":"ExKits.Utils.Buffer","doc":"A simple buffer queue implementation using ETS tables.\n\nThis module provides a way to create a buffer queue with a specified capacity\nand allows items to be put into and taken out of the queue. If the queue is\nfull, `put` will return `{:error, :full}`. If the queue is empty, `take` will\nblock until an item is available.","ref":"ExKits.Utils.Buffer.html"},{"type":"module","title":"Examples - ExKits.Utils.Buffer","doc":"iex> {:ok, pid} = ExKits.Utils.Buffer.start_link(name: :my_queue, size: 10)\n    iex> ExKits.Utils.Buffer.put(:my_queue, [1, 2, 3])\n    :ok\n    iex> ExKits.Utils.Buffer.take(:my_queue)\n    [1, 2, 3]","ref":"ExKits.Utils.Buffer.html#module-examples"},{"type":"function","title":"ExKits.Utils.Buffer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExKits.Utils.Buffer.html#child_spec/1"},{"type":"function","title":"ExKits.Utils.Buffer.put/3","doc":"Adds the given items to the buffer queue.\n\nIf the buffer queue is full, this function will return `{:error, :full}`.","ref":"ExKits.Utils.Buffer.html#put/3"},{"type":"function","title":"Examples - ExKits.Utils.Buffer.put/3","doc":"iex> {:ok, _pid} = ExKits.Utils.Buffer.start_link(:my_queue, 10)\n    iex> ExKits.Utils.Buffer.put(:my_queue, [1, 2, 3])\n    :ok\n    iex> ExKits.Utils.Buffer.put(:my_queue, [4, 5, 6], 1000)\n    :ok\n    iex> ExKits.Utils.Buffer.put(:my_queue, [7, 8, 9, 10, 11])\n    {:error, :full}","ref":"ExKits.Utils.Buffer.html#put/3-examples"},{"type":"function","title":"ExKits.Utils.Buffer.size/2","doc":"Returns the number of items in the buffer queue.","ref":"ExKits.Utils.Buffer.html#size/2"},{"type":"function","title":"Examples - ExKits.Utils.Buffer.size/2","doc":"iex> {:ok, _pid} = ExKits.Utils.Buffer.start_link(:my_queue, 10)\n    iex> ExKits.Utils.Buffer.put(:my_queue, [1, 2, 3])\n    :ok\n    iex> ExKits.Utils.Buffer.size(:my_queue)\n    3","ref":"ExKits.Utils.Buffer.html#size/2-examples"},{"type":"function","title":"ExKits.Utils.Buffer.start_link/1","doc":"Starts a new buffer process.","ref":"ExKits.Utils.Buffer.html#start_link/1"},{"type":"function","title":"Options - ExKits.Utils.Buffer.start_link/1","doc":"* `:name` - The name of the buffer process. Must be an atom\n* `:size` - The maximum number of items the buffer can hold","ref":"ExKits.Utils.Buffer.html#start_link/1-options"},{"type":"function","title":"Examples - ExKits.Utils.Buffer.start_link/1","doc":"iex> {:ok, pid} = ExKits.Utils.Buffer.start_link(name: :my_queue, size: 10)\n    iex> ExKits.Utils.Buffer.put(:my_queue, [1, 2, 3])","ref":"ExKits.Utils.Buffer.html#start_link/1-examples"},{"type":"function","title":"ExKits.Utils.Buffer.stop/1","doc":"","ref":"ExKits.Utils.Buffer.html#stop/1"},{"type":"function","title":"ExKits.Utils.Buffer.take/2","doc":"Removes and returns items from the buffer queue.\n\nIf the buffer queue is empty, this function will block until an item is available.","ref":"ExKits.Utils.Buffer.html#take/2"},{"type":"function","title":"Examples - ExKits.Utils.Buffer.take/2","doc":"iex> {:ok, _pid} = ExKits.Utils.Buffer.start_link(:my_queue, 10)\n    iex> ExKits.Utils.Buffer.put(:my_queue, [1, 2, 3])\n    :ok\n    iex> ExKits.Utils.Buffer.take(:my_queue)\n    [1, 2, 3]\n    iex> ExKits.Utils.Buffer.take(:my_queue)\n    []","ref":"ExKits.Utils.Buffer.html#take/2-examples"},{"type":"type","title":"ExKits.Utils.Buffer.t/0","doc":"","ref":"ExKits.Utils.Buffer.html#t:t/0"},{"type":"module","title":"ExKits.Utils.Const","doc":"This module is similar to ets in that it provides a storage for Erlang terms that can be accessed in constant time,\nbut with the difference that persistent_term has been highly optimized for reading terms at the expense of writing and updating terms.\n\nWhen a persistent term is updated or deleted, a global garbage collection pass is run to scan all processes for the deleted term,\nand to copy it into each process that still uses it.\n\nTherefore, persistent_term is suitable for storing Erlang terms that are frequently accessed but never or infrequently updated.","ref":"ExKits.Utils.Const.html"},{"type":"function","title":"ExKits.Utils.Const.get/1","doc":"","ref":"ExKits.Utils.Const.html#get/1"},{"type":"function","title":"ExKits.Utils.Const.put/2","doc":"put a key-value pair into the persistent term storage\nNOTE: very very expensive, use with caution","ref":"ExKits.Utils.Const.html#put/2"},{"type":"function","title":"Examples - ExKits.Utils.Const.put/2","doc":"iex> ExKits.Utils.Const.put(:key, :val)","ref":"ExKits.Utils.Const.html#put/2-examples"},{"type":"module","title":"ExKits.Utils.Debug","doc":"Debug tools","ref":"ExKits.Utils.Debug.html"},{"type":"function","title":"ExKits.Utils.Debug.debug/1","doc":"","ref":"ExKits.Utils.Debug.html#debug/1"},{"type":"function","title":"ExKits.Utils.Debug.stacktrace/1","doc":"","ref":"ExKits.Utils.Debug.html#stacktrace/1"},{"type":"protocol","title":"ExKits.Utils.Param","doc":"","ref":"ExKits.Utils.Param.html"},{"type":"function","title":"ExKits.Utils.Param.to_integer/1","doc":"","ref":"ExKits.Utils.Param.html#to_integer/1"},{"type":"function","title":"ExKits.Utils.Param.to_map/1","doc":"","ref":"ExKits.Utils.Param.html#to_map/1"},{"type":"function","title":"ExKits.Utils.Param.to_string/1","doc":"","ref":"ExKits.Utils.Param.html#to_string/1"},{"type":"type","title":"ExKits.Utils.Param.t/0","doc":"All the types that implement this protocol.","ref":"ExKits.Utils.Param.html#t:t/0"},{"type":"module","title":"ExKits.Utils.Time","doc":"时间相关工具","ref":"ExKits.Utils.Time.html"},{"type":"function","title":"ExKits.Utils.Time.china_now/0","doc":"","ref":"ExKits.Utils.Time.html#china_now/0"},{"type":"function","title":"ExKits.Utils.Time.china_today/0","doc":"","ref":"ExKits.Utils.Time.html#china_today/0"},{"type":"function","title":"ExKits.Utils.Time.date_to_datetime/2","doc":"","ref":"ExKits.Utils.Time.html#date_to_datetime/2"},{"type":"function","title":"ExKits.Utils.Time.datetime_to_naive/1","doc":"","ref":"ExKits.Utils.Time.html#datetime_to_naive/1"},{"type":"function","title":"ExKits.Utils.Time.datetime_to_str/2","doc":"","ref":"ExKits.Utils.Time.html#datetime_to_str/2"},{"type":"function","title":"ExKits.Utils.Time.datetime_to_ts/1","doc":"","ref":"ExKits.Utils.Time.html#datetime_to_ts/1"},{"type":"function","title":"ExKits.Utils.Time.naive_now/1","doc":"","ref":"ExKits.Utils.Time.html#naive_now/1"},{"type":"function","title":"ExKits.Utils.Time.naive_to_datetime/2","doc":"","ref":"ExKits.Utils.Time.html#naive_to_datetime/2"},{"type":"function","title":"ExKits.Utils.Time.naive_to_datetime!/2","doc":"","ref":"ExKits.Utils.Time.html#naive_to_datetime!/2"},{"type":"function","title":"ExKits.Utils.Time.now/1","doc":"","ref":"ExKits.Utils.Time.html#now/1"},{"type":"function","title":"ExKits.Utils.Time.now!/1","doc":"","ref":"ExKits.Utils.Time.html#now!/1"},{"type":"function","title":"ExKits.Utils.Time.str_to_datetime/2","doc":"","ref":"ExKits.Utils.Time.html#str_to_datetime/2"},{"type":"function","title":"ExKits.Utils.Time.timestamp/1","doc":"get current timestamp","ref":"ExKits.Utils.Time.html#timestamp/1"},{"type":"function","title":"Example - ExKits.Utils.Time.timestamp/1","doc":"iex> Common.TimeTool.timestamp(:seconds)\n1534466694\niex> Common.TimeTool.timestamp(:milli_seconds)\n1534466732335\niex> Common.TimeTool.timestamp(:micro_seconds)\n1534466750683862\niex> Common.TimeTool.timestamp(:nano_seconds)\n1534466778949821000","ref":"ExKits.Utils.Time.html#timestamp/1-example"},{"type":"function","title":"ExKits.Utils.Time.ts_to_datetime/2","doc":"","ref":"ExKits.Utils.Time.html#ts_to_datetime/2"},{"type":"exception","title":"ExKits.Utils.Exception","doc":"General exception with an optional string, map, or Keyword list stored\nin exception details","ref":"ExKits.Utils.Exception.html"},{"type":"function","title":"ExKits.Utils.Exception.new/2","doc":"","ref":"ExKits.Utils.Exception.html#new/2"},{"type":"type","title":"ExKits.Utils.Exception.t/0","doc":"","ref":"ExKits.Utils.Exception.html#t:t/0"}],"content_type":"text/markdown"}